## dbt-redshift 1.9.4 - April 28, 2025

### Features

- Retry `could not open relation with OID` query exceptions ([#1014](https://github.com/dbt-labs/dbt-adapters/issues/1014))
- Added `retry_all` profile config param to retry on all redshift_connector exceptions ([#1014](https://github.com/dbt-labs/dbt-adapters/issues/1014))

### Fixes

- `datetime.datetime.utcnow()` is deprecated as of Python 3.12 ([#980](https://github.com/dbt-labs/dbt-adapters/issues/980))
